@@ -42,7 +42,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
     lateinit var currentTile: Tile
 
     @Transient
-    val movement = UnitMovementAlgorithms(this)
+    val movement = UnitMovement(this)
 
     @Transient
     val upgrade = UnitUpgradeManager(this)
@@ -414,6 +414,14 @@ class MapUnit : IsPartOfGameInfoSerialization {
         return getMatchingUniques(UniqueType.HealAdjacentUnits).sumOf { it.params[0].toInt() }
     }
 
+    fun getHealAmountForCurrentTile() = when {
+        isEmbarked() -> 0 // embarked units can't heal
+        health >= 100 -> 0 // No need to heal if at max health
+        hasUnique(UniqueType.HealOnlyByPillaging, checkCivInfoUniques = true) -> 0
+        else -> rankTileForHealing(getTile())
+    }
+    fun canHealInCurrentTile() = getHealAmountForCurrentTile() > 0
+
     // Only military land units can truly "garrison"
     fun canGarrison() = isMilitary() && baseUnit.isLandUnit()
 
@@ -566,11 +574,11 @@ class MapUnit : IsPartOfGameInfoSerialization {
         for (unique in civ.getMatchingUniques(UniqueType.ProvidesGoldWheneverGreatPersonExpended)) {
             gainedStats.gold += (100 * civ.gameInfo.speed.goldCostModifier).toInt()
         }
+        val speedModifiers = civ.gameInfo.speed.statCostModifiers
         for (unique in civ.getMatchingUniques(UniqueType.ProvidesStatsWheneverGreatPersonExpended)) {
-            val uniqueStats = unique.stats
-            val speedModifiers = civ.gameInfo.speed.statCostModifiers
-            for (stat in uniqueStats) {
-                uniqueStats[stat.key] = stat.value * speedModifiers[stat.key]!!
+            val uniqueStats = unique.stats.clone()
+            for ((stat, value) in uniqueStats) {
+                uniqueStats[stat] = value * speedModifiers[stat]!!
             }
             gainedStats.add(uniqueStats)
         }
