@@ -9,7 +9,6 @@ import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.badlogic.gdx.utils.Align
 import com.unciv.Constants
 import com.unciv.GUI
-import com.unciv.UncivGame
 import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.civilization.managers.TechManager
 import com.unciv.models.UncivSound
@@ -116,6 +115,8 @@ class TechPickerScreen(
         }
         else civTech.techsToResearch = tempTechsToResearch
 
+        civTech.updateResearchProgress()
+
         game.settings.addCompletedTutorialTask("Pick technology")
 
         game.popScreen()
@@ -370,7 +371,7 @@ class TechPickerScreen(
 
         val previousSelectedTech = selectedTech
         selectedTech = tech
-        descriptionLabel.setText(tech?.getDescription(civInfo.gameInfo.ruleset))
+        descriptionLabel.setText(tech?.getDescription(civInfo))
 
         if (!switchFromWorldScreen)
             return
@@ -425,7 +426,7 @@ class TechPickerScreen(
     }
 
     private fun getTechProgressLabel(techs: List<String>): String {
-        val progress = techs.sumOf { tech -> civTech.researchOfTech(tech) }
+        val progress = techs.sumOf { tech -> civTech.researchOfTech(tech) } + civTech.getOverflowScience(techs.first())
         val techCost = techs.sumOf { tech -> civInfo.tech.costOfTech(tech) }
         return "(${progress}/${techCost})"
     }
