@@ -323,15 +323,17 @@ class WorldScreen(
         if(uiEnabled){
             displayTutorialsOnUpdate()
 
+            bottomUnitTable.update()
+
             updateSelectedCiv()
 
             if (fogOfWar) minimapWrapper.update(selectedCiv)
             else minimapWrapper.update(viewingCiv)
 
-            bottomUnitTable.update()
             bottomTileInfoTable.updateTileTable(mapHolder.selectedTile)
             bottomTileInfoTable.x = stage.width - bottomTileInfoTable.width
             bottomTileInfoTable.y = if (game.settings.showMinimap) minimapWrapper.height else 0f
+
             battleTable.update()
 
             displayTutorialTaskOnUpdate()
@@ -632,7 +634,14 @@ class WorldScreen(
 
         updateMultiplayerStatusButton()
 
+        statusButtons.wrap(false)
         statusButtons.pack()
+        val maxWidth = stage.width - techPolicyAndDiplomacy.width - 25f
+        if(statusButtons.width > maxWidth) {
+            statusButtons.width = maxWidth
+            statusButtons.wrap()
+            statusButtons.pack()
+        }
         statusButtons.setPosition(stage.width - statusButtons.width - 10f, topBar.y - statusButtons.height - 10f)
     }
 
